==> zio-aws-pinpointemail_3-5.17.155.2-sources.jar: zio/aws/pinpointemail/model/GetDedicatedIpResponse.scala <==
package zio.aws.pinpointemail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetDedicatedIpResponse(
    dedicatedIp: Option[zio.aws.pinpointemail.model.DedicatedIp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpointemail.model.GetDedicatedIpResponse = {
    import GetDedicatedIpResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpointemail.model.GetDedicatedIpResponse
      .builder()
      .optionallyWith(dedicatedIp.map(value => value.buildAwsValue()))(
        _.dedicatedIp
      )
      .build()
  }
  def asReadOnly: zio.aws.pinpointemail.model.GetDedicatedIpResponse.ReadOnly =
    zio.aws.pinpointemail.model.GetDedicatedIpResponse.wrap(buildAwsValue())
}
object GetDedicatedIpResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpointemail.model.GetDedicatedIpResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpointemail.model.GetDedicatedIpResponse =
      zio.aws.pinpointemail.model
        .GetDedicatedIpResponse(dedicatedIp.map(value => value.asEditable))
    def dedicatedIp: Option[zio.aws.pinpointemail.model.DedicatedIp.ReadOnly]
    def getDedicatedIp
        : ZIO[Any, AwsError, zio.aws.pinpointemail.model.DedicatedIp.ReadOnly] =
      AwsError.unwrapOptionField("dedicatedIp", dedicatedIp)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpointemail.model.GetDedicatedIpResponse
  ) extends zio.aws.pinpointemail.model.GetDedicatedIpResponse.ReadOnly {
    override val dedicatedIp
        : Option[zio.aws.pinpointemail.model.DedicatedIp.ReadOnly] = scala
      .Option(impl.dedicatedIp())
      .map(value => zio.aws.pinpointemail.model.DedicatedIp.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpointemail.model.GetDedicatedIpResponse
  ): zio.aws.pinpointemail.model.GetDedicatedIpResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-pinpointemail_3-5.19.8.4-sources.jar: zio/aws/pinpointemail/model/GetDedicatedIpResponse.scala <==
package zio.aws.pinpointemail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetDedicatedIpResponse(
    dedicatedIp: Optional[zio.aws.pinpointemail.model.DedicatedIp] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpointemail.model.GetDedicatedIpResponse = {
    import GetDedicatedIpResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpointemail.model.GetDedicatedIpResponse
      .builder()
      .optionallyWith(dedicatedIp.map(value => value.buildAwsValue()))(
        _.dedicatedIp
      )
      .build()
  }
  def asReadOnly: zio.aws.pinpointemail.model.GetDedicatedIpResponse.ReadOnly =
    zio.aws.pinpointemail.model.GetDedicatedIpResponse.wrap(buildAwsValue())
}
object GetDedicatedIpResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpointemail.model.GetDedicatedIpResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpointemail.model.GetDedicatedIpResponse =
      zio.aws.pinpointemail.model
        .GetDedicatedIpResponse(dedicatedIp.map(value => value.asEditable))
    def dedicatedIp: Optional[zio.aws.pinpointemail.model.DedicatedIp.ReadOnly]
    def getDedicatedIp
        : ZIO[Any, AwsError, zio.aws.pinpointemail.model.DedicatedIp.ReadOnly] =
      AwsError.unwrapOptionField("dedicatedIp", dedicatedIp)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpointemail.model.GetDedicatedIpResponse
  ) extends zio.aws.pinpointemail.model.GetDedicatedIpResponse.ReadOnly {
    override val dedicatedIp
        : Optional[zio.aws.pinpointemail.model.DedicatedIp.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dedicatedIp())
        .map(value => zio.aws.pinpointemail.model.DedicatedIp.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpointemail.model.GetDedicatedIpResponse
  ): zio.aws.pinpointemail.model.GetDedicatedIpResponse.ReadOnly = new Wrapper(
    impl
  )
}
